# Generated by Django 1.9.13 on 2017-08-08 11:45

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models

FCM_DJANGO_SETTINGS = getattr(settings, "FCM_DJANGO_SETTINGS", {})
USER_MODEL = FCM_DJANGO_SETTINGS.get("USER_MODEL", settings.AUTH_USER_MODEL)


class Migration(migrations.Migration):

    dependencies = [
        ("fcm_django", "0004_auto_20181128_1642"),
    ]

    operations = [
        migrations.AlterField(
            model_name="fcmdevice",
            name="user",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to=USER_MODEL,
            ),
        ),
    ]
