# Generated by Django 3.1.12 on 2021-12-24 12:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fcm_django', '0007_auto_20211001_1440'),
    ]

    operations = [
        migrations.AlterField(
            model_name='fcmdevice',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
